pub struct Input {
pub periodStart: FHIRDate,
pub periodEnd: FHIRDate,
pub measure: Option<FHIRString>,
pub reportType: Option<FHIRCode>,
pub subject: Option<FHIRString>,
pub practitioner: Option<FHIRString>,
pub lastReceivedOn: Option<FHIRDateTime>,
}Fields
periodStart: FHIRDateThe start of the measurement period. In keeping with the semantics of the date parameter used in the FHIR search operation, the period will start at the beginning of the period implied by the supplied timestamp. E.g. a value of 2014 would set the period start to be 2014-01-01T00:00:00 inclusive
periodEnd: FHIRDateThe end of the measurement period. The period will end at the end of the period implied by the supplied timestamp. E.g. a value of 2014 would set the period end to be 2014-12-31T23:59:59 inclusive
measure: Option<FHIRString>The measure to evaluate. This parameter is only required when the operation is invoked on the resource type, it is not used when invoking the operation on a Measure instance
reportType: Option<FHIRCode>The type of measure report: subject, subject-list, or population. If not specified, a default value of subject will be used if the subject parameter is supplied, otherwise, population will be used
subject: Option<FHIRString>Subject for which the measure will be calculated. If not specified, the measure will be calculated for all subjects that meet the requirements of the measure. If specified, the measure will only be calculated for the referenced subject(s)
practitioner: Option<FHIRString>Practitioner for which the measure will be calculated. If specified, the measure will be calculated only for subjects that have a primary relationship to the identified practitioner
lastReceivedOn: Option<FHIRDateTime>The date the results of this measure were last received. This parameter is only valid for patient-level reports and is used to indicate when the last time a result for this patient was received. This information can be used to limit the set of resources returned for a patient-level report